{"title": "Index", "search": "search", "path": "./", "relative": "./", "author": ["El Cato", "email - not set", "me.png", "Welcome to the docs for El Cato static block generator", [["Chat", "Matrix", "https://riot.im/app/#/room/#elcato:matrix.org"], ["Software", "GitLab", "https://gitlab.com/python-open-source-library-collection/elcato"]]], "blog": ["https://olymk2.gitlab.io/elcato/", "ElCato", "domain - not set", "me.jpg", "Welcome to getting started with ElCato"]}